@@ -40,13 +40,17 @@ class PluginMeta(type):
             'always-on', default=instance.alwaysOn)
 
         instance.__init__(*args, **kwargs)
+
         if always_on:
             instance.register()
-        else:
-            if switch is not None:
-                short_opt, long_opt, help = switch
-                instance.addOption(
-                    instance._register_cb, short_opt, long_opt, help)
+
+        if switch is not None:
+            short_opt, long_opt, help = switch
+            if always_on:  # always-on plugins should hide their options
+                help = argparse.SUPPRESS
+            instance.addOption(
+                instance._register_cb, short_opt, long_opt, help)
+
         return instance
 
 
@@ -75,7 +79,8 @@ class Plugin(six.with_metaclass(PluginMeta)):
 
        Example::
 
-         commandLineSwitch = ('B', 'buffer-output', 'Buffer output during tests')
+         commandLineSwitch = ('B', 'buffer-output', 'Buffer output during
+         tests')
 
     .. attribute :: configSection
 
@@ -126,7 +131,8 @@ class Plugin(six.with_metaclass(PluginMeta)):
                     self.session.hooks.register(method, plugin)
 
     def _register_cb(self, *_):
-        self.register()
+        if not self.registered:
+            self.register()
 
     def addFlag(self, callback, short_opt, long_opt, help_text=None):
         """Add command-line flag that takes no arguments
@@ -260,12 +266,14 @@ class PluginInterface(object):
     """
     preRegistrationMethods = ('pluginsLoaded', 'handleArgs')
     methods = (
-        'loadTestsFromModule', 'loadTestsFromNames',
-        'handleFile', 'startTestRun', 'startTest', 'stopTest',
-        'loadTestsFromName', 'loadTestsFromTestCase',
-        'stopTestRun', 'matchPath', 'matchDirPath', 'getTestCaseNames',
-        'runnerCreated', 'resultCreated', 'testOutcome', 'wasSuccessful',
-        'resultStop', 'setTestOutcome', 'describeTest',
+        'loadTestsFromModule', 'loadTestsFromNames', 'handleFile',
+        'startLayerSetup', 'startLayerSetupTest', 'stopLayerSetupTest',
+        'stopLayerSetup', 'startTestRun', 'startTest', 'stopTest',
+        'startLayerTeardown', 'startLayerTeardownTest',
+        'stopLayerTeardownTest', 'stopLayerTeardown', 'loadTestsFromName',
+        'loadTestsFromTestCase', 'stopTestRun', 'matchPath', 'matchDirPath',
+        'getTestCaseNames', 'runnerCreated', 'resultCreated', 'testOutcome',
+        'wasSuccessful', 'resultStop', 'setTestOutcome', 'describeTest',
         'reportStartTest', 'reportError', 'reportFailure', 'reportSkip',
         'reportSuccess', 'reportExpectedFailure', 'reportUnexpectedSuccess',
         'reportOtherOutcome', 'outcomeDetail', 'beforeErrorList',
@@ -407,6 +415,146 @@ class ResultCreatedEvent(Event):
         super(ResultCreatedEvent, self).__init__(**kw)
 
 
+class StartLayerSetupEvent(Event):
+
+    """Event fired before running a layer setup.
+
+    .. attribute :: layer
+
+       The current layer instance, for which setup is about to run.
+    """
+    _attrs = Event._attrs + ('layer',)
+
+    def __init__(self, layer, **kw):
+        self.layer = layer
+        super(StartLayerSetupEvent, self).__init__(**kw)
+
+
+class StopLayerSetupEvent(Event):
+
+    """Event fired after running a layer setup.
+
+    .. attribute :: layer
+
+       The current layer instance, for which setup just ran.
+    """
+    _attrs = Event._attrs + ('layer',)
+
+    def __init__(self, layer, **kw):
+        self.layer = layer
+        super(StopLayerSetupEvent, self).__init__(**kw)
+
+
+class StartLayerSetupTestEvent(Event):
+
+    """Event fired before test cases setups in layers.
+
+    .. attribute :: layer
+
+       The current layer instance.
+
+    .. attribute :: test
+
+       The test instance for which the setup is about to run.
+    """
+    _attrs = Event._attrs + ('layer', 'test')
+
+    def __init__(self, layer, test, **kw):
+        self.layer = layer
+        self.test = test
+        super(StartLayerSetupTestEvent, self).__init__(**kw)
+
+
+class StopLayerSetupTestEvent(Event):
+
+    """Event fired after test cases setups in layers.
+
+    .. attribute :: layer
+
+       The current layer instance.
+
+    .. attribute :: test
+
+       The test instance for which the setup just finished.
+    """
+    _attrs = Event._attrs + ('layer', 'test')
+
+    def __init__(self, layer, test, **kw):
+        self.layer = layer
+        self.test = test
+        super(StopLayerSetupTestEvent, self).__init__(**kw)
+
+
+class StartLayerTeardownEvent(Event):
+
+    """Event fired before running a layer teardown.
+
+    .. attribute :: layer
+
+       The current layer instance, for which teardown is about to run.
+    """
+    _attrs = Event._attrs + ('layer',)
+
+    def __init__(self, layer, **kw):
+        self.layer = layer
+        super(StartLayerTeardownEvent, self).__init__(**kw)
+
+
+class StopLayerTeardownEvent(Event):
+
+    """Event fired after running a layer teardown.
+
+    .. attribute :: layer
+
+       The current layer instance, for which teardown just ran.
+    """
+    _attrs = Event._attrs + ('layer',)
+
+    def __init__(self, layer, **kw):
+        self.layer = layer
+        super(StopLayerTeardownEvent, self).__init__(**kw)
+
+
+class StartLayerTeardownTestEvent(Event):
+
+    """Event fired before test cases teardowns in layers.
+
+    .. attribute :: layer
+
+       The current layer instance.
+
+    .. attribute :: test
+
+       The test instance for which teardown is about to run.
+    """
+    _attrs = Event._attrs + ('layer', 'test')
+
+    def __init__(self, layer, test, **kw):
+        self.layer = layer
+        self.test = test
+        super(StartLayerTeardownTestEvent, self).__init__(**kw)
+
+
+class StopLayerTeardownTestEvent(Event):
+
+    """Event fired after test cases teardowns in layers.
+
+    .. attribute :: layer
+
+       The current layer instance.
+
+    .. attribute :: test
+
+       The test instance for which teardown just ran.
+    """
+    _attrs = Event._attrs + ('layer', 'test')
+
+    def __init__(self, layer, test, **kw):
+        self.layer = layer
+        self.test = test
+        super(StopLayerTeardownTestEvent, self).__init__(**kw)
+
+
 class StartTestRunEvent(Event):
 
     """Event fired when test run is about to start.
@@ -920,6 +1068,9 @@ class ResultSuccessEvent(Event):
        Set this to ``True`` to indicate that the test run was
        successful. If no plugin sets the ``success`` to
        ``True``, the test run fails.
+       Should be initialized to ``None`` to indicate that the status has not
+       been set yet (so that plugins can always differentiate an explicit
+       failure in an earlier hook from no pass/fail status having been set yet.
 
     """
     _attrs = Event._attrs + ('result', 'success')
