@@ -19,19 +19,19 @@ of the test function is the "case" argument, followed by the other parameters::
 
     from nose2.tools import such
     from nose2.tools.params import params
-    
+
     with such.A('foo') as it:
         @it.should('do bar')
         @params(1,2,3)
         def test(case, bar):
             case.assert_(isinstance(bar, int))
-    
+
         @it.should('do bar and extra')
         @params((1, 2), (3, 4) ,(5, 6))
         def testExtraArg(case, bar, foo):
             case.assert_(isinstance(bar, int))
             case.assert_(isinstance(foo, int))
-    
+
     it.createTests(globals())
 
 """
@@ -40,6 +40,7 @@ of the test function is the "case" argument, followed by the other parameters::
 # unittest2 is Copyright (c) 2001-2010 Python Software Foundation; All
 # Rights Reserved. See: http://docs.python.org/license.html
 
+import sys
 import functools
 import logging
 import types
@@ -47,7 +48,6 @@ import unittest
 
 from nose2 import exceptions, util
 from nose2.events import Plugin
-from nose2.compat import unittest as ut2
 from nose2.plugins.loader.testclasses import MethodTestCase
 
 
@@ -55,11 +55,11 @@ log = logging.getLogger(__name__)
 __unittest = True
 
 
-class ParamsFunctionCase(ut2.FunctionTestCase):
+class ParamsFunctionCase(unittest.FunctionTestCase):
 
     def __init__(self, name, func, **args):
         self._funcName = name
-        ut2.FunctionTestCase.__init__(self, func, **args)
+        unittest.FunctionTestCase.__init__(self, func, **args)
 
     def __repr__(self):
         return self._funcName
@@ -116,9 +116,9 @@ class Parameters(Plugin):
         module = event.module
         try:
             result = util.test_from_name(name, module)
-        except (AttributeError, ImportError) as e:
+        except (AttributeError, ImportError):
             event.handled = True
-            return event.loader.failedLoadTests(name, e)
+            return event.loader.failedLoadTests(name, sys.exc_info())
         if result is None:
             # we can't find it - let the default case handle it
             return
