@@ -73,7 +73,6 @@ import unittest
 import sys
 
 from nose2 import events, util
-from nose2.compat import unittest as ut2
 
 __unittest = True
 
@@ -117,9 +116,9 @@ class TestClassLoader(events.Plugin):
         module = event.module
         try:
             result = util.test_from_name(name, module)
-        except (AttributeError, ImportError) as e:
+        except (AttributeError, ImportError):
             event.handled = True
-            return event.loader.failedLoadTests(name, e)
+            return event.loader.failedLoadTests(name, sys.exc_info())
         if result is None:
             return
         parent, obj, name, index = result
@@ -149,9 +148,8 @@ class TestClassLoader(events.Plugin):
                      MethodTestCase(cls), cls.__module__)(name)
                         for name in names])
             except:
-                _, ev, _ = sys.exc_info()
                 return event.loader.suiteClass(
-                    event.loader.failedLoadTests(cls.__name__, ev))
+                    event.loader.failedLoadTests(cls.__name__, sys.exc_info()))
         if evt.extraTests:
             loaded_suite.addTests(evt.extraTests)
         # ... add extra tests
@@ -187,13 +185,13 @@ class TestClassLoader(events.Plugin):
 # to prevent unit2 discover from running this as a test, need to
 # hide it inside of a factory func. ugly!
 def MethodTestCase(cls):
-    class _MethodTestCase(ut2.TestCase):
+    class _MethodTestCase(unittest.TestCase):
 
         def __init__(self, method):
             self.method = method
             self._name = "%s.%s.%s" % (cls.__module__, cls.__name__, method)
             self.obj = cls()
-            ut2.TestCase.__init__(self, 'runTest')
+            unittest.TestCase.__init__(self, 'runTest')
 
         @classmethod
         def setUpClass(klass):
