@@ -17,6 +17,7 @@ pkg1.test.test_things.SomeTests.test_ok
 # param method index
 
 """
+import sys
 from nose2.tests._common import FunctionalTestCase, support_file
 
 
@@ -221,6 +222,8 @@ class TestLoadingErrors(FunctionalTestCase):
             'scenario/module_import_err',
             '-v',
             'test_import_err')
+        self.assertTestRunOutputMatches(proc, stderr='ImportError: booms')
+        self.assertTestRunOutputMatches(proc, stderr='Traceback \(most recent call last\):')
         self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
         self.assertEqual(proc.poll(), 1)
 
@@ -229,6 +232,8 @@ class TestLoadingErrors(FunctionalTestCase):
             'scenario/module_import_err',
             '-v',
             'test_import_err.test')
+        self.assertTestRunOutputMatches(proc, stderr='ImportError: booms')
+        self.assertTestRunOutputMatches(proc, stderr='Traceback \(most recent call last\):')
         self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
         self.assertEqual(proc.poll(), 1)
 
@@ -237,6 +242,8 @@ class TestLoadingErrors(FunctionalTestCase):
             'scenario/module_import_err',
             '-v',
             'test_import_err.Test')
+        self.assertTestRunOutputMatches(proc, stderr='ImportError: booms')
+        self.assertTestRunOutputMatches(proc, stderr='Traceback \(most recent call last\):')
         self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
         self.assertEqual(proc.poll(), 1)
 
@@ -245,9 +252,61 @@ class TestLoadingErrors(FunctionalTestCase):
             'scenario/module_import_err',
             '-v',
             'test_import_err.Test.test')
+        self.assertTestRunOutputMatches(proc, stderr='ImportError: booms')
+        self.assertTestRunOutputMatches(proc, stderr='Traceback \(most recent call last\):')
         self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
         self.assertEqual(proc.poll(), 1)
 
+    def test_import_error_package(self):
+        proc = self.runIn(
+            'scenario/module_import_err',
+            '-v',
+            'pkg')
+        # In this case, there should not be an AttributeError since we only
+        # import pkg, which should work.
+        self.assertTestRunOutputMatches(proc, stderr='ImportError: Failed to import test module: pkg.test_import_err')
+        self.assertTestRunOutputMatches(proc, stderr='Traceback \(most recent call last\):')
+        self.assertTestRunOutputMatches(proc, stderr='ValueError: booms')
+        # 3 tests should run, and only one should fail. We're testing that a
+        # loading error does not prevent from running other tests.
+        self.assertTestRunOutputMatches(proc, stderr='Ran 3 tests')
+        self.assertTestRunOutputMatches(proc, stderr='FAILED \(errors=1\)')
+        self.assertEqual(proc.poll(), 1)
+
+    def test_import_error_module_in_package(self):
+        proc = self.runIn(
+            'scenario/module_import_err',
+            '-v',
+            'pkg.test_import_err')
+        # In this case, there should not be an ImportError. The import of
+        # pkg.test_import_err fails due with a `ValueError`, and this is the
+        # one we are expecting.
+        self.assertTestRunOutputMatches(proc, stderr='AttributeError: ')
+        self.assertTestRunOutputMatches(proc, stderr='ValueError: booms')
+        self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
+        self.assertEqual(proc.poll(), 1)
+
+    def test_import_error_unknown_module_in_package(self):
+        proc = self.runIn(
+            'scenario/module_import_err',
+            '-v',
+            'pkg.test_does_not_exit')
+        # In this case, there should not be an ImportError. The import of
+        # pkg.test_import_err fails due with a `ValueError`, and this is the
+        # one we are expecting.
+        self.assertTestRunOutputMatches(proc, stderr='AttributeError: ')
+
+        # py3.6 introduced ModuleNotFoundError, a subclass of ImportError
+        if sys.version_info < (3, 6):
+            importerr = 'ImportError: No module named'
+        else:
+            importerr = 'ModuleNotFoundError: No module named'
+        self.assertTestRunOutputMatches(proc, stderr=importerr)
+
+        self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
+        self.assertEqual(proc.poll(), 1)
+
+
 
 class TestTestClassLoading(FunctionalTestCase):
 
@@ -300,11 +359,11 @@ class TestTestClassLoading(FunctionalTestCase):
         self.assertTestRunOutputMatches(proc, stderr='Ran 1 test')
         self.assertTestRunOutputMatches(proc, stderr='FAILED')
         self.assertEqual(proc.poll(), 1)
-    
+
     def test_expected_failures(self):
         proc = self.runIn(
             'scenario/expected_failures',
             '-v',
             'expected_failures')
         self.assertTestRunOutputMatches(proc, stderr=r'FAILED \(failures=1, expected failures=1, unexpected successes=1\)')
-        
\ No newline at end of file
+
